from importlib.metadata import PackageNotFoundError, version

from sfreeze.freeze import s3_freeze, s3_thaw


try:
    __version__ = version(__name__)
except PackageNotFoundError:
    print('package is not installed!\n'
          'Install in editable/develop mode via (from the top of this repo):\n'
          '   python -m pip install -e .\n'
          'Or, to just get the version number use:\n'
          '   python setup.py --version')


__all__ = [
    's3_freeze',
    's3_thaw',
]



import pickle
from uuid import uuid4
from base64 import decodebytes, encodebytes

import boto3

S3_CLIENT = boto3.client('s3')


def s3_freeze(obj, bucket, key=None, **kwargs):
    binary = pickle.dumps(obj)
    if not key:
        key = 'sfreeze' + str(uuid4())
    S3_CLIENT.put_object(Bucket=bucket, Key=key, Body=binary, **kwargs)
    obj_id = encode(f'{bucket}:{key}')
    return obj_id


def s3_thaw(obj_id, **kwargs):
    bucket, key = decode(obj_id).split(':')
    response = S3_CLIENT.get_object(Bucket=bucket, Key=key, **kwargs)
    binary = response['Body'].read()
    return pickle.loads(binary)


def encode(string):
    return encodebytes(string.encode()).decode()


def decode(string):
    return decodebytes((string.encode())).decode()



import os

from setuptools import find_packages, setup

_HERE = os.path.abspath(os.path.dirname(__file__))
with open(os.path.join(_HERE, 'README.md'), 'r') as f:
    long_desc = f.read()

setup(
    name='sfreeze',
    use_scm_version=True,
    description='A python tool for freezing objects in AWS S3',
    long_description=long_desc,
    long_description_content_type='text/markdown',

    url='https://github.com/Jlrine2/sfreeze',

    license='BSD',
    include_package_data=True,

    classifiers=[
        'License :: OSI Approved :: BSD License',
        'Natural Language :: English',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
    ],

    python_requires='~=3.8',

    install_requires=[
        'boto3',
    ],

    extras_require={},

    packages=find_packages(),

    zip_safe=False,
)